@@ -12,12 +12,12 @@ def main():
     parser.add_argument(
         "-d", "--cfgdir",
         default="cfg",
-        help="config directory that maps to cfg:// root."
+        help="config directory that maps to cfg:// root. (default: `cfg`)"
     )
     args, _ = parser.parse_known_args()
     cfgs = parse_configs(cfg_root=args.cfgdir)
-    return cfgs[args.recipe]()
-
+    _main = cfgs[args.recipe]
+    return _main(recursive=False)
 
 if __name__ == "__main__":
     main()
